@@ -268,7 +268,7 @@ HTML;
                 $stmt->execute([
                     md5($row['carddata']),
                     strlen($row['carddata']),
-                    $row['id']
+                    $row['id'],
                 ]);
             }
             $this->aSuccess[] = 'etag and size was recalculated for cards';
@@ -304,7 +304,7 @@ HTML;
                 $stmt1->execute([
                     'addressbooks/' . basename($row['uri']),
                     '{http://calendarserver.org/ns/}me-card',
-                    serialize(new \Sabre\DAV\Xml\Property\Href($row['vcardurl']))
+                    serialize(new \Sabre\DAV\Xml\Property\Href($row['vcardurl'])),
                 ]);
             }
             $this->aSuccess[] = 'vcardurl was migrated to the propertystorage system';
@@ -499,6 +499,11 @@ SQL
     );
             $this->aSuccess[] = 'Migrated calendars table';
         }
+        if (version_compare($sVersionFrom, '0.9.4', '<')) {
+            $pdo->exec("UPDATE calendarinstances SET access = 1 WHERE access IS NULL");
+            $pdo->exec("UPDATE calendarinstances SET share_invitestatus = 2 WHERE share_invitestatus IS NULL");
+            $this->aSuccess[] = 'Updated default values in calendarinstances table';
+        }
 
         $this->updateConfiguredVersion($sVersionTo);
 
